@@ -21,9 +21,25 @@ sub new
 
   my $self = $class->SUPER::new(%args);
 
+  my $xml_schema = '';
+  my $currency_supported = '';
+
+  if ($args{gco}->reader()) {
+
+    my $reader = $args{gco}->reader();
+
+    $xml_schema = $reader->get(Google::Checkout::XML::Constants::XML_SCHEMA);
+    $currency_supported = $reader->get(Google::Checkout::XML::Constants::CURRENCY_SUPPORTED);
+
+  } else {
+
+    $xml_schema = $args{gco}->{__xml_schema};
+    $currency_supported = $args{gco}->{__currency_supported};
+
+  }
+
   $self->add_element(name => Google::Checkout::XML::Constants::CHECKOUT_ROOT,
-                     attr => [xmlns => 
-                     $args{gco}->reader()->get(Google::Checkout::XML::Constants::XML_SCHEMA)]);
+                     attr => [xmlns => $xml_schema]);
 
   if ($args{cart})
   {
@@ -72,8 +88,7 @@ sub new
         $self->add_element(name => Google::Checkout::XML::Constants::ITEM_PRICE,
                            data => $_->get_price(), close => 1,
                            attr => [Google::Checkout::XML::Constants::ITEM_CURRENCY => 
-                                    $args{gco}->reader->get(
-                           Google::Checkout::XML::Constants::CURRENCY_SUPPORTED)]);
+                                    $currency_supported]);
         $self->add_element(name => Google::Checkout::XML::Constants::QUANTITY,
                            data =>$_->get_quantity(), close => 1);
 
@@ -167,8 +182,7 @@ sub new
       $self->add_element(name => Google::Checkout::XML::Constants::PRICE,
                          data => $price, close => 1,
                          attr => [Google::Checkout::XML::Constants::ITEM_CURRENCY =>
-                                  $args{gco}->reader->get(
-                                  Google::Checkout::XML::Constants::CURRENCY_SUPPORTED)]);
+                                  $currency_supported]);
 
       my $restriction = $shipping->get_restriction();
       if ($restriction)
