@@ -21,9 +21,23 @@ sub new
 
   my $self = $class->SUPER::new(%args);
 
+  my $xml_schema = '';
+  my $currency_supported = '';
+
+  if ($args{gco}->reader()) {
+
+    my $reader = $args{gco}->reader();
+    
+    $xml_schema = $reader->get(Google::Checkout::XML::Constants::XML_SCHEMA);
+    $currency_supported = $reader->get(Google::Checkout::XML::Constants::CURRENCY_SUPPORTED);
+
+  } else {
+    $xml_schema = $args{gco}->{__xml_schema};
+    $currency_supported = $args{gco}->{__currency_supported};
+  }
+
   $self->add_element(name => $args{command}->get_name,
-                     attr => [xmlns => $args{gco}->reader()->get(
-                              Google::Checkout::XML::Constants::XML_SCHEMA),
+                     attr => [xmlns => $xml_schema,
                               Google::Checkout::XML::Constants::ORDER_NUMBER => 
                                 $args{command}->get_order_number]);
 
@@ -33,8 +47,7 @@ sub new
                        name => Google::Checkout::XML::Constants::AMOUNT, 
                        data => $args{command}->get_amount,
                        attr => [Google::Checkout::XML::Constants::ITEM_CURRENCY => 
-                                $args{gco}->reader()->get(
-                                  Google::Checkout::XML::Constants::CURRENCY_SUPPORTED)]);
+                                $currency_supported]);
   }
 
   return bless $self => $class;
